@@ -34,21 +34,18 @@ class SyncOnly(PointError):
 
 
 class RequestError(PointError):
+    default_url = None
     default_status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
     default_detail = 'A server error occurred.'
-    default_url = None
 
-    def __init__(self, url=None, detail=None, status_code=None):
+    def __init__(self, url=None, status_code=None, detail=None):
         self.__url = self.default_url if url is None else url
-        self.__detail = self.default_detail if detail is None else detail
         self.__status_code = self.default_status_code if status_code is None else status_code
-
-    def __str__(self):
-        return f'{self.__status_code}:{self.__url}:{self.__detail}'
+        self.__detail = self.default_detail if detail is None else detail
 
     @property
     def detail(self):
-        return self.__detail
+        return f'{self.__url}:{self.__status_code}:{self.__detail}'
 
 
 class ServerError(RequestError):
@@ -132,9 +129,9 @@ class Point:
                         self._cache = status.HTTP_404_NOT_FOUND
                         raise NotFound404(self._point_id.url)
                     else:
-                        raise ClientError(self._point_id.url, response.json(), response.status_code)
+                        raise ClientError(self._point_id.url, response.status_code, response.json())
                 else:
-                    raise ServerError(self._point_id.url, response.text, response.status_code)
+                    raise ServerError(self._point_id.url, response.status_code, response.text)
 
 
 class ObjectPoint(Point):
