@@ -88,33 +88,56 @@ class PhotoVerificationProcessReadContract(Contract):
     message = serializers.CharField(max_length=64, allow_blank=True)
 
 
-profiles_verification_request_photo_verification = ID(SERVICE, 'verification', 'request_photo_verification')
-profiles_verification_request_video_verification = ID(SERVICE, 'verification', 'request_video_verification')
-profiles_verification_auto_verification_process = ID(SERVICE, 'verification', 'auto_verification_process')
-profiles_verification_video_verification_process = ID(SERVICE, 'verification', 'video_verification_process')
-profiles_verification_photo_verification_process = ID(SERVICE, 'verification', 'photo_verification_process')
+class RequestPhotoVerificationID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'request_photo_verification'
+
+
+class RequestVideoVerificationID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'request_video_verification'
+
+
+class AutoVerificationProcessID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'auto_verification_process'
+
+
+class VideoVerificationProcessID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'video_verification_process'
+
+
+class PhotoVerificationProcessID(ID):
+    _service = SERVICE
+    _app = 'verification'
+    _view_set = 'photo_verification_process'
 
 
 class RequestPhotoVerificationPoint(CreatePointMixin, ContractPoint):
-    _point_id = profiles_verification_request_photo_verification
+    _point_id = RequestPhotoVerificationID()
     _create_contract = RequestPhotoVerificationCreateContract
 
 
 class RequestVideoVerificationPoint(CreatePointMixin, ContractPoint):
-    _point_id = profiles_verification_request_video_verification
+    _point_id = RequestVideoVerificationID()
     _create_contract = RequestVideoVerificationCreateContract
 
 
 class AutoVerificationProcessPoint(ListPointMixin, ContractPoint):
-    _point_id = profiles_verification_auto_verification_process
+    _point_id = AutoVerificationProcessID()
     _read_contract = AutoVerificationProcessReadContract
 
 
 class VideoVerificationProcessPoint(ListPointMixin, ContractPoint):
-    _point_id = profiles_verification_video_verification_process
+    _point_id = VideoVerificationProcessID()
     _read_contract = VideoVerificationProcessReadContract
 
 
 class PhotoVerificationProcessPoint(ListPointMixin, ContractPoint):
-    _point_id = profiles_verification_photo_verification_process
+    _point_id = PhotoVerificationProcessID()
     _read_contract = PhotoVerificationProcessReadContract
